@@ -2,9 +2,12 @@ use crate::plus_offset_from;
 
 #[inline(always)]
 pub fn _memchr_impl(buf: &[u8], c: u8) -> Option<usize> {
-    if buf.len() == 0 {
+    if buf.is_empty() {
         return None;
     }
+    if buf[0] == c {
+        return Some(0);
+    }
     #[cfg(target_pointer_width = "128")]
     let r = _start_chr_128(buf, c);
     #[cfg(target_pointer_width = "64")]
@@ -226,7 +229,7 @@ pub(crate) fn _memchr_remaining_7_bytes_impl(
         }
     }
     // the remaining data is the max: 3 bytes.
-    _memchr_remaining_3_bytes_impl(buf_ptr,  cc as u16, start_ptr, end_ptr)
+    _memchr_remaining_3_bytes_impl(buf_ptr, cc as u16, start_ptr, end_ptr)
 }
 
 #[inline(always)]
